package notify
import "go.etcd.io/etcd/pkg/v3/notify"
Index ¶
Types ¶
type Notifier ¶
type Notifier struct {
// contains filtered or unexported fields
}
Notifier is a thread safe struct that can be used to send notification about some event to multiple consumers.
func NewNotifier ¶
func NewNotifier() *Notifier
NewNotifier returns new notifier
func (*Notifier) Notify ¶
func (n *Notifier) Notify()
Notify closes the channel passed to consumers and creates new channel to used for next notification.
func (*Notifier) Receive ¶
func (n *Notifier) Receive() <-chan struct{}
Receive returns channel that can be used to wait for notification. Consumers will be informed by closing the channel.
Source Files ¶
notify.go
- Version
- v3.6.7 (latest)
- Published
- Dec 17, 2025
- Platform
- linux/amd64
- Imports
- 1 packages
- Last checked
- 4 months ago –
Tools for package owners.